@@ -1,6 +1,7 @@
 import click
 
 from slai.modules.runtime import detect_runtime, detect_credentials
+from slai.exceptions import NoCredentialsFound
 from slai_cli import log
 from slai_cli.create import project_generator
 from slai_cli.exceptions import ProjectExistsException
@@ -13,7 +14,12 @@ def create(name, profile):
     """Create a new slai project."""
 
     runtime = detect_runtime()
-    credentials = detect_credentials(runtime=runtime, profile_name=profile)
+
+    try:
+        credentials = detect_credentials(runtime=runtime, profile_name=profile)
+    except NoCredentialsFound:
+        log.warn("Invalid credentials.")
+        return
 
     try:
         pg = project_generator.ProjectGenerator(
