@@ -1,6 +1,7 @@
 import os
 import click
 import git
+import yaml
 
 from jinja2 import Template
 from pathlib import Path
@@ -24,14 +25,13 @@ class ProjectGenerator:
         self,
         *,
         project_name,
-        client_id,
-        client_secret,
-        profile,
+        credentials,
     ):
-        self.cli_client = get_cli_client()
-        self.client_id = client_id
-        self.client_secret = client_secret
-        self.profile = profile
+        self.cli_client = get_cli_client(
+            client_id=credentials["client_id"],
+            client_secret=credentials["client_secret"],
+        )
+        self.credentials = credentials
         self.project_name = project_name
 
     def create_new_project(self):
@@ -56,6 +56,9 @@ class ProjectGenerator:
         # clone template repository
         self._clone_template_repo(local_path=local_path)
 
+        # store profile in project credentials file
+        self._store_local_credentials()
+
         # generate template files
         self._create_project_files(local_path=local_path)
 
@@ -70,6 +73,12 @@ class ProjectGenerator:
 
         return local_path
 
+    def _store_local_credentials(self):
+        cwd = os.getcwd()
+
+        with open(f"{cwd}/.slai/credentials.yml", "w") as f_out:
+            yaml.dump(self.credentials, f_out, default_flow_style=False)
+
     def _generate_project_variables(self, project_name):
         try:
             self.project = self.cli_client.create_project(name=self.project_name)
@@ -87,9 +96,6 @@ class ProjectGenerator:
             "SLAI_SERVICE_NAME": self.service_name,
             "SLAI_PROJECT_ID": self.project["id"],
             "SLAI_PROJECT_NAME": project_name,
-            "SLAI_CLIENT_ID": self.client_id,
-            "SLAI_CLIENT_SECRET": self.client_secret,
-            "SLAI_PROFILE_NAME": self.profile,
         }
 
         return variables
