@@ -2,7 +2,6 @@ import click
 import sys
 
 from functools import update_wrapper
-from slai_cli.run import commands as run
 from slai_cli.create import commands as create
 from slai_cli.model import commands as model
 from slai_cli.profile import commands as profile
@@ -26,7 +25,6 @@ def entry_point(profile):
 
 
 def main():
-    entry_point.add_command(run.run)
     entry_point.add_command(create.create)
     entry_point.add_command(model.model)
     entry_point.add_command(profile.profile)
