@@ -70,7 +70,17 @@ def checkout_model_version(model_name, version_name=None):
     local_model_config = local_config_helper.get_local_model_config(
         model_name=model_name, model_client=model_client
     )
-    model_version_id = local_model_config["model_version_id"]
+    model_version_id = local_model_config.get("model_version_id")
+    if model_version_id is None:
+        model_version_id = model_client.model["model_version_id"]
+
+    model_version = cli_client.retrieve_model_version_by_id(
+        model_version_id=model_version_id
+    )
+
+    log.action(
+        f"Current model version is: {model_version['name']} <{model_version_id}>"
+    )
 
     # if a version name was specified, check if a version with that name exists
     if version_name is not None:
