@@ -5,6 +5,7 @@ from pathlib import Path
 from requests.exceptions import HTTPError
 
 from slai_cli import log
+from slai_cli.modules.deployment_checks import check_handler_imports
 from slai_cli.decorators import requires_slai_project
 from slai_cli.exceptions import InvalidHandlerSyntax
 from slai_cli.modules.docker_client import DockerClient
@@ -12,46 +13,11 @@ from slai_cli import constants
 from slai_cli.errors import handle_error
 from slai_cli.create.local_config_helper import LocalConfigHelper
 
+from slai.clients.cli import get_cli_client
 from slai.clients.model import get_model_client
 from slai.clients.project import get_project_client
 
 
-def _install_requirement_interactively(*, model_name, docker_client, requirement):
-    exit_code = docker_client.install_requirement(
-        model_name=model_name, requirement=requirement
-    )
-    if exit_code != constants.REQUIREMENTS_RETURN_CODE_SUCCESS:
-        log.warn(f"Failed to install: {requirement}")
-
-
-def _check_handler_imports(*, model_name, docker_client):
-    exit_code = docker_client.check_handler_imports(
-        model_name=model_name,
-    )
-    if exit_code == constants.REQUIREMENTS_RETURN_CODE_MISSING_DEP:
-        if log.action_confirm(
-            "Looks like a dependency is missing, would you like to add it interactively?"
-        ):
-            requirement = log.action_prompt(
-                "Add python dependency (e.g. numpy==1.20.1): ",
-                type=str,
-            )
-
-            return _install_requirement_interactively(
-                model_name=model_name,
-                docker_client=docker_client,
-                requirement=requirement,
-            )
-        else:
-            return constants.REQUIREMENTS_RETURN_CODE_EXIT
-
-    elif exit_code == constants.REQUIREMENTS_RETURN_CODE_IMPORT_ERROR:
-        log.warn("Trainer script failed due to import error.")
-        return constants.REQUIREMENTS_RETURN_CODE_IMPORT_ERROR
-
-    return constants.REQUIREMENTS_RETURN_CODE_SUCCESS
-
-
 def _merge_requirements(model_artifact_requirements, model_handler_requirements):
     requirements = {}
     for req, version in model_artifact_requirements.items():
@@ -82,9 +48,17 @@ def _create_model_deployment(*, model_client, model_version_id, docker_client):
         raise InvalidHandlerSyntax("invalid_model_handler")
 
     handler_data = base64.b64encode(handler_source.encode("utf-8")).decode()
-    model_artifact = model_client.get_latest_model_artifact(
-        model_version_id=model_version_id
-    )
+    try:
+        model_artifact = model_client.get_latest_model_artifact(
+            model_version_id=model_version_id
+        )
+    except HTTPError as e:
+        if e.response.status_code == 400:
+            error_msg = e.response.json()["detail"]["non_field_errors"][0]
+            handle_error(error_msg=error_msg)
+            return None
+        else:
+            raise
 
     # check model requirements in local container
     model_artifact_requirements = {}
@@ -95,22 +69,13 @@ def _create_model_deployment(*, model_client, model_version_id, docker_client):
     if import_return_code == constants.REQUIREMENTS_RETURN_CODE_SUCCESS:
         model_artifact_requirements = model_artifact["artifact_requirements"]
 
-    # check if imports are valid
-    log.action("Checking if model handler imports are valid...")
-    import_return_code = _check_handler_imports(
+    # check if model handler imports are valid
+    import_return_code = check_handler_imports(
         model_name=model_name, docker_client=docker_client
     )
-    while (
-        import_return_code != constants.REQUIREMENTS_RETURN_CODE_SUCCESS
-        and import_return_code != constants.REQUIREMENTS_RETURN_CODE_EXIT
-    ):
-        import_return_code = _check_handler_imports(
-            model_name=model_name,
-            docker_client=docker_client,
-        )
 
     if import_return_code != constants.REQUIREMENTS_RETURN_CODE_SUCCESS:
-        log.warn(f"Deployment failed due to import error.")
+        log.warn("Deployment failed due to import error.")
         return None
 
     log.action("Model handler imports look valid.")
@@ -150,7 +115,14 @@ def deploy_model(*, model_name, version):
     project_name = project["name"]
     project_id = project["id"]
 
-    docker_client = DockerClient(project_name=project_name, project_id=project_id)
+    cli_client = get_cli_client()
+
+    try:
+        docker_client = DockerClient(project_name=project_name, project_id=project_id)
+    except RuntimeError:
+        log.warn("ERROR: Unable to connect to docker, is it installed/running?")
+        return
+
     model_client = get_model_client(model_name=model_name, project_name=project_name)
 
     local_config_helper = LocalConfigHelper()
@@ -162,7 +134,12 @@ def deploy_model(*, model_name, version):
     if model_version_id is None:
         model_version_id = model_client.model["model_version_id"]
 
-    log.action(f"Using model version: {model_version_id}")
+    model_version = cli_client.retrieve_model_version_by_id(
+        model_version_id=model_version_id
+    )
+
+    log.action(f"Using model version: {model_version['name']} <{model_version_id}>")
+
     try:
         model_deployment = _create_model_deployment(
             model_client=model_client,
