@@ -3,6 +3,7 @@ import click
 
 from slai_cli.profile import configure as _configure
 from slai_cli.profile import list as _list
+from slai.modules.runtime import ValidRuntimes
 
 
 @click.group()
@@ -13,7 +14,7 @@ def profile():
 @click.argument("profile_name")
 @profile.command()
 def configure(profile_name):
-    _configure.get_credentials(profile_name=profile_name)
+    _configure.get_credentials(profile_name=profile_name, runtime=ValidRuntimes.Local)
 
 
 @profile.command()
